# CLI

See all available commands:

```bash
marvin --help
```

## Chat
    
```bash
marvin chat --name Squilliam --personality "Has seen better comebacks from a turkey sandwich"
```

## Database management

```bash
marvin database --help
```

**WARNING**: This will drop all tables and data in the database.
```bash
marvin database reset
```

## Run the server

```bash
marvin server start
```

## Setup OpenAI
    
```bash
marvin setup-openai
```